==> dnet-mapreduce-jobs-1.0.0-20170627.153716-10-sources.jar: eu/dnetlib/data/mapreduce/hbase/broker/Topic.java <==
package eu.dnetlib.data.mapreduce.hbase.broker;

/**
 * Created by claudio on 20/07/16.
 */
public enum Topic {

	/*
      <int name="mesheuropmc">1185961</int>
      <int name="arxiv">842888</int>
      <int name="jel">485877</int>
      <int name="ddc">323948</int>
      <int name="acm">311403</int>
      <int name="rvk">11889</int>

	 */

	// ENRICHMENT MISSING
	ENRICH_MISSING_OA_VERSION("ENRICH/MISSING/OPENACCESS_VERSION"), ENRICH_MISSING_ABSTRACT("ENRICH/MISSING/ABSTRACT"), ENRICH_MISSING_PUBLICATION_DATE(
			"ENRICH/MISSING/PUBLICATION_DATE"), ENRICH_MISSING_PID("ENRICH/MISSING/PID"), ENRICH_MISSING_PROJECT("ENRICH/MISSING/PROJECT"),
	ENRICH_MISSING_SUBJECT_MESHEUROPMC("ENRICH/MISSING/SUBJECT/MESHEUROPMC"),
	ENRICH_MISSING_SUBJECT_ARXIV("ENRICH/MISSING/SUBJECT/ARXIV"),
	ENRICH_MISSING_SUBJECT_JEL("ENRICH/MISSING/SUBJECT/JEL"),
	ENRICH_MISSING_SUBJECT_DDC("ENRICH/MISSING/SUBJECT/DDC"),
	ENRICH_MISSING_SUBJECT_ACM("ENRICH/MISSING/SUBJECT/ACM"),
	ENRICH_MISSING_SUBJECT_RVK("ENRICH/MISSING/SUBJECT/RVK"),


	// ENRICHMENT MORE
	ENRICH_MORE_PID("ENRICH/MORE/PID"), ENRICH_MORE_OA_VERSION("ENRICH/MORE/OPENACCESS_VERSION"), ENRICH_MORE_ABSTRACT(
			"ENRICH/MORE/ABSTRACT"), ENRICH_MORE_PUBLICATION_DATE("ENRICH/MORE/PUBLICATION_DATE"), ENRICH_MORE_PROJECT("ENRICH/MORE/PROJECT"),
	ENRICH_MORE_SUBJECT_MESHEUROPMC("ENRICH/MORE/SUBJECT/MESHEUROPMC"),
	ENRICH_MORE_SUBJECT_ARXIV("ENRICH/MORE/SUBJECT/ARXIV"),
	ENRICH_MORE_SUBJECT_JEL("ENRICH/MORE/SUBJECT/JEL"),
	ENRICH_MORE_SUBJECT_DDC("ENRICH/MORE/SUBJECT/DDC"),
	ENRICH_MORE_SUBJECT_ACM("ENRICH/MORE/SUBJECT/ACM"),
	ENRICH_MORE_SUBJECT_RVK("ENRICH/MORE/SUBJECT/RVK"),

	// ADDITION
	ADD_BY_PROJECT("ADD/BY_PROJECT");

	Topic(final String value) {
		this.value = value;
	}

	protected String value;

	public String getValue() {
		return this.value;
	}
}

==> dnet-mapreduce-jobs-1.0.2-20170920.104642-47-sources.jar: eu/dnetlib/data/mapreduce/hbase/broker/Topic.java <==
package eu.dnetlib.data.mapreduce.hbase.broker;

/**
 * Created by claudio on 20/07/16.
 */
public enum Topic {

	// ENRICHMENT MISSING
	ENRICH_MISSING_OA_VERSION("ENRICH/MISSING/OPENACCESS_VERSION"),
	ENRICH_MISSING_ABSTRACT("ENRICH/MISSING/ABSTRACT"),
	ENRICH_MISSING_PUBLICATION_DATE("ENRICH/MISSING/PUBLICATION_DATE"),
	ENRICH_MISSING_PID("ENRICH/MISSING/PID"),
	ENRICH_MISSING_PROJECT("ENRICH/MISSING/PROJECT"),
	ENRICH_MISSING_SUBJECT_MESHEUROPMC("ENRICH/MISSING/SUBJECT/MESHEUROPMC"),
	ENRICH_MISSING_SUBJECT_ARXIV("ENRICH/MISSING/SUBJECT/ARXIV"),
	ENRICH_MISSING_SUBJECT_JEL("ENRICH/MISSING/SUBJECT/JEL"),
	ENRICH_MISSING_SUBJECT_DDC("ENRICH/MISSING/SUBJECT/DDC"),
	ENRICH_MISSING_SUBJECT_ACM("ENRICH/MISSING/SUBJECT/ACM"),
	ENRICH_MISSING_SUBJECT_RVK("ENRICH/MISSING/SUBJECT/RVK"),

	// ENRICHMENT MORE
	ENRICH_MORE_PID("ENRICH/MORE/PID"),
	ENRICH_MORE_OA_VERSION("ENRICH/MORE/OPENACCESS_VERSION"),
	ENRICH_MORE_ABSTRACT("ENRICH/MORE/ABSTRACT"),
	ENRICH_MORE_PUBLICATION_DATE("ENRICH/MORE/PUBLICATION_DATE"),
	ENRICH_MORE_PROJECT("ENRICH/MORE/PROJECT"),
	ENRICH_MORE_SUBJECT_MESHEUROPMC("ENRICH/MORE/SUBJECT/MESHEUROPMC"),
	ENRICH_MORE_SUBJECT_ARXIV("ENRICH/MORE/SUBJECT/ARXIV"),
	ENRICH_MORE_SUBJECT_JEL("ENRICH/MORE/SUBJECT/JEL"),
	ENRICH_MORE_SUBJECT_DDC("ENRICH/MORE/SUBJECT/DDC"),
	ENRICH_MORE_SUBJECT_ACM("ENRICH/MORE/SUBJECT/ACM"),
	ENRICH_MORE_SUBJECT_RVK("ENRICH/MORE/SUBJECT/RVK"),

	// ADDITION
	ADD_BY_PROJECT("ADD/BY_PROJECT");

	Topic(final String value) {
		this.value = value;
	}

	protected String value;

	public String getValue() {
		return this.value;
	}
}
